#ifndef cdssmap_H
#define cdssmap_H

#include "c3d.h"

//---------------------------------------------------------------------------------------
// CDSSVertMap
// Contains a lookup which maps original vertices and surfaces to their subdivision counterparts.
// This only maps a surface/vertex to its "final subdivided" counterpart - this class does
//    not account for other vertices/surfaces.
class CDSSMap
{

private:

   // Structure containing original + final-location subdivision vertex
   class CVertMap
   {
   public:
      Vertex *original;
      Vertex *subdivided;
      CVertMap()
      {
         original = NULL;
         subdivided = NULL;
      }
      void CopyFrom( CVertMap *m )
      {
         this->original = m->original;
         this->subdivided = m->subdivided;
      }
   };

   // Vertex map
   CVertMap *mVerts;
   //Number of vertices in map
   unsigned int mNumVerts;

   // Return a list of objects currently selected in AC3D - works in any select mode
   static void GetSelectedACObjects( List **out );
   // Recursively add objects with geometry to the list
   static void ListAddObjectWithSSRecurse( List **out, ACObject *o );

   // Clear the vertex/surface maps
   void Clear();

   // Sort the vertex map
   void QSortVertMap( int left, int right );

public:

   // Constructor creates a vertex/surface map based on the current AC3D selection.
   // This ensures that our map can stay in contiguous memory
   // block for fast-searchable subscript access.
   CDSSMap();
   ~CDSSMap();

   // Returns whether objects with subdivisions are part of the selection
   bool ContainsSubdivisions()
   {
      return ( mNumVerts > 0 );
   }

   // Get the subdivided vertex for an original, or just return the original if no subdivided vertex exists
   Vertex *GetSSVertex( Vertex *original );

};
//---------------------------------------------------------------------------------------

#endif
