#ifndef cduvmap_H
#define cduvmap_H

#include "cdssmap.h"

//---------------------------------------------------------------------------------------
// CDUVMap
class CDUVMap
{

private:

   // Returns the world center/min/max of the selected surfaces
   // Pass a NULL to ignore a param
   void GetSelectionBounds( List *surfs, Vertex *vmin, Vertex *vmax, Vertex *vcnt );

   // Fix UV wrapping for spherical/cylindrical maps to get rid of wrapping problems
   void FixUVWrap( Surface *s );

   // Space polar coordinates to the center of the attached surface
   void SpacePolarCoordinates( List *surfs, int axis, Vertex *vcenter );

public:

   // Subdivision map
   CDSSMap mSSMap;
   // Whether to consider subdivisions when calculating texture coordinates
   bool mUseSS;
   // Polar spacing
   bool mSpacePoles;

   CDUVMap();
   ~CDUVMap();

   // Apply planar texture mapping to the specified surfaces
   // PLANE:
   // 1 = front
   // 2 = back
   // 3 = left
   // 4 = right
   // 5 = top
   // 6 = bottom
   void ApplyPlanar( List *surfs, int plane );
   // Apply box texture mapping to the specified surfaces
   void ApplyBox( List *surfs );
   // Apply spherical texture mapping to the specified surfaces
   void ApplySpherical( List *surfs, int axis );
   // Apply cylindrical texture mapping to the specified surfaces
   void ApplyCylindrical( List *surfs, int axis );
   // Apply cylindrical cap texture mapping to the specified surfaces
   void ApplyCylindricalCap( List *surfs, int axis );

   // Apply global texture mapping to the specified surfaces
   void ApplyGlobal( List *surfs, float scalex, float scaley, float offsetx, float offsety, float rotation );

};
//---------------------------------------------------------------------------------------

#endif
